libname lance 'I:\aqtag\ezm\PMstaffpaper\data'; run;
options mprint mlogic symbolgen; run;
%macro boxplot(poll,year);
data prep;
%if &poll=pmc %then %do;
set lance.lance_coarse;
%end;
%else %do;
set lance.lance_fine;
%end;
year=year(zdate);
month=month(zdate);
if location in('SUBURBAN', 'URBAN AND CENTER CITY');
if pmreg=0 then delete;  *this deletes hawaii, alaska, etc;
%if &year ge 2000 %then %do; *this allows me to put in a year at a time;
if year=&year;
%end;
run;
proc sort data=prep; by pmregdesc month; run;

*this proc summary is used to calculate the percentiles;
proc summary data=prep;
by pmregdesc month;
var v;
output out=prepbox p5=p5 p25=p25 p50=p50 p75=p75 p95=p95;
run;

*this code allows me to trick SAS to make a boxplot without whiskers;
data prepbox2;
set prepbox;
p5=p25;
p95=p75;
run;

proc transpose data=prepbox2 out=prepbox3; by pmregdesc month; 
var p5 p25 p50 p75 p95;
run;

*this code allows me to put the month names along the x-axis;
*format will be called following proc boxplot;
proc format;
value mfmt
	.5-1.5='Jan'
	1.5-2.5='Feb'
	2.5-3.5='Mar'
	3.5-4.5='Apr'
	4.5-5.5='May'
	5.5-6.5='Jun'
	6.5-7.5='Jul'
	7.5-8.5='Aug'
	8.5-9.5='Sep'
	9.5-10.5='Oct'
	10.5-11.5='Nov'
	11.5-12.5='Dec';
run;

*this summary will be used for the labeling above the boxplots;
proc summary data=prep; by pmregdesc month;
var v;
output out=anno1 n=nobs mean=mean p75=y;
run;

*this code is to put the number of sites above the boxplots;
data anno2;
set anno1;
length tobs $4.0;
length function $8.0;
ysys='2';
xsys='2';
position='2';
function='label';
x=month;
y=y+1;
tobs=trim(left(put(nobs,4.0)));
text=tobs;
if month ne .;
run;

*this code is used to draw the line for the mean;
data anno3;
set anno1;
length function $8.0;
ysys='2';
xsys='2';
if month eq 1 then function='move';
else function='draw';
x=month;
y=mean;
color='black';
run;

data anno4;
set anno2 anno3;
size=1;
run;

proc sort data=anno4; by pmregdesc month; run;
proc sort data=prepbox3; by pmregdesc month; run;

filename gsasfile "I:\aqtag\ezm\PMstaffpaper\graphs\bxplotmon&year&poll..cgm";
goptions reset=all dev=cgmflwa gaccess=gsasfile ftext='HELVETICA' ctext=black htext=2
      cback=white colors=(blue);

axis1 value=(h=1.5)
label=none
%if &poll=pmc %then %do;
order=(-5 to 45 by 5);
%end;
%else %do;
order=(0 to 40 by 5);
%end;

axis2 value=(h=1.5)
label=none;

proc boxplot data=prepbox3;
by pmregdesc;
format COL1 3.;
plot COL1*month / totpanels=1 noframe cboxes=black blocklabtype=scaled
   vaxis=axis1 haxis=axis2 caxis=black ctext=black annotate=anno4;
format month mfmt.; *this comes from proc format above;
symbol v=none c=black r=20;
run;
%mend boxplot;
*use pmc for PM10-2.5 and pmf for PM2.5;
*use 2000,2001,2002 for individual years, leave blank to combine all 3 years;
%boxplot(pmc) 
run;



