
%macro mapit(dataset,cntystat,dn);
********************************************************************;
*  black&white map                                                  ;
*  dataset  - SAS dataset containing the criteria pollutant data.   ;
*             Must contain the following variable names:            ;
*             STATE (State FIPS code)                               ;
*             COUNTY (County FIPS code)                             ;
*             The county stat (whatever name given is fine)         ;
*                                                                   ;

********************************************************************;
libname map 'g:\user\share\schmidty';

************************  MAP  START  ******************************;
goptions reset=all dev=cgmflwa  gaccess = gsasfile
          colors=(white grayef graybf gray00);


filename gsasfile "d:\pm naaqs\summer03\&dn..cgm";

%if %upcase(&dataset) eq FINE and %upcase(&cntystat) eq AMEAN  %then %do;
proc format;
value fmt
 low - 12="0 < x <= 12"
 12.1 -  15="12 < x <= 15"
 15.1 -  18="15 < x <= 18"
 18.1 - high="x > 18";
%end;
%else %if %upcase(&dataset) eq FINE and %upcase(&cntystat) eq P98  %then %do;
proc format;
value fmt
 low - 30="0 < x <= 30"
 31 -  40="30 < x <= 40"
 41 -  65="40 < x <= 65"
 66 - high="x > 65";
%end;
%else %if %upcase(&dataset) eq COARSE and %upcase(&cntystat) eq AMEAN  %then %do;
proc format;
value fmt
 low - 10="0 < x <= 10"
 10.1 -  15="10 < x <= 15"
 15.1-  25="15 < x <= 25"
 25.1 - high="x > 25";
%end;
%else %if %upcase(&dataset) eq COARSE and %upcase(&cntystat) eq P98  %then %do;
proc format;
value fmt
 low - 25="0 < x <= 25"
 26 -  45="25 < x <= 45"
 46 -  75="45 < x <= 75"
 76 - high="x > 75";
%end;
%else %if %upcase(&dataset) eq TEN and %upcase(&cntystat) eq AMEAN  %then %do;
proc format;
value fmt
 low - 20="0 < x <= 20"
 20.1 -  30="20 < x <= 30"
 30.1 -  50="30 < x <= 50"
 50.1 - high="x > 50";
%end;
%else %if %upcase(&dataset) eq TEN and %upcase(&cntystat) eq P98  %then %do;
proc format;
value fmt
 low - 50="0 < x <= 50"
 51 -  75="50 < x <= 75"
 76 -  150="75 < x <= 150"
 151 - high="x > 150";
%end;
run;

proc sort data=&dataset; by state county;

legend1 label=(h=1.1 f=HWCGM002 c=black
               "Concentration ug/m3")
        value=(h=1.1 f=HWCGM002 c=black)
        cborder=white cframe=white cshadow=white;

label &cntystat='00'x;        *-----> unprintable hexadecimal string;
format &cntystat fmt.;


*------------------------SET UP US MAP----------------------------;
data usmap;
     merge &dataset(in=match) map.usall2 ;
     by state county;
     if match = 1 or county = 0;
proc sort; by &cntystat;
*--------------------DRAW AND SHADE US MAP------------------------;
proc gmap map=usmap data=&dataset all;
     format &cntystat fmt.;
     id state county;
     choro &cntystat / discrete
                      cempty=black
                      coutline=gray
legend=legend1;
pattern value=msolid;
run;
quit;
%mend;

%mapit(ten,p98,tenp98);