%macro parmpull(lib,parm,styear,endyear,flag,userid,userpasswd);
*       This macro pulls raw data from AQS, pulls and assimilates       *;
*       sampling frequency info from AQS, and computes data capture     *;
*       rates, means, and 98th percentiles                              *;
*           lib     :   A sas libname designation                       *;
*           styear  :   start year for the retrieval                    *;
*           endyear :   end year for the retrieval                      *;
*                       Note: 3 year period required, styear >= 1999    *;
*           flag    :   y to include flags with data & n for no flags   *;
*                       with data                                       *;
*           vname   :   assigns a name to the actual concentration      *;
*                       values (for raw data saves)                     *;

*PART 1 - PULL RAW DATA;

%let sd=01-JAN-&styear;
%let ed=31-DEC-&endyear;

proc sql;
     connect to oracle (user=&userid password=&userpasswd path="aqsprod" buffsize=100);
     create table temp as
     select * from connection to oracle (
select  sites.cc_cn_stt_state_code||sites.cc_cn_county_code||sites.site_id as site,
        monitors.poc as poc,
		monitors.pa_parameter_code as parm,
        current_data.sampling_begin_datetime as datetime,
        protocols.sm_methodology_code as meth,
%if %upcase(&flag) eq Y %then  %do;
        qualifier_details.qu_qualifier_code as flag,
%end;
 		current_data.REPORTED_sample_value as v
        from    monitors monitors,
        monitor_protocols monitor_protocols,
        protocols protocols,
%if %upcase(&flag) eq Y %then %do;
        qualifier_details qualifier_details,
%end;
        current_data current_data,
        sites sites
where   monitors.mo_id = monitor_protocols.mo_mo_id and
        protocols.pro_id = monitor_protocols.pro_pro_id and
        monitor_protocols.mo_mo_id = current_data.mp_mo_mo_id and
        monitor_protocols.mp_id = current_data.mp_mp_id and
%if %upcase(&flag) eq Y %then %do;
        current_data.rd_id = qualifier_details.rd_rd_id(+) and
%end;
        sites.si_id = monitors.si_si_id and
        sites.cc_cn_stt_state_code <> 'CC' and
        sites.cc_cn_stt_state_code <> '80' and
        protocols.sd_duration_code = '7' and
        monitors.pa_parameter_code = %unquote(%str(%'&parm%')) and
        upper(current_data.status_ind) = upper('p') and
        current_data.sampling_begin_datetime >= %unquote(%str(%'&sd%')) and
        current_data.sampling_begin_datetime <= %unquote(%str(%'&ed%'))
order by 1, 2, 3
);
%put &sqlxrc; *debug sql;
%put &sqlxmsg; *debug sql;
disconnect from oracle;
quit;




data temp2;
set temp;
zdate=datepart(datetime);
hr=hour(datetime);
drop datetime;
format zdate mmddyy10.;
run;

proc sort; by site poc zdate;

data tempraw (keep= site st cou poc zdate v f1-f10 q meth hr year parm);
length f1-f10 $1. flag $2.;
array f(10) f1-f10;
retain n f1-f10;
set temp2; by site poc zdate;
st=substr(site,1,2);
cou=substr(site,3,3);
q=qtr(zdate);
v=round(v-.049999,.1);
year=year(zdate);
if first.zdate then do;
n=0;
f1=' '; f2=' '; f3=' '; f4=' '; f5=' '; f6=' '; f7=' '; f8=' '; f9=' '; f10=' ';
end;
n+1;
if flag ne ' ' then f(n)=flag;
if last.zdate then output;

data tempraw2; set tempraw;
if (parm= '88101' and meth in ('116','117','118','119','120','123')) or
(parm IN ('81102' '85101') and meth in ('062','063','064','065','071','073','076','079','081',
'098','122','124','125', '126','127','130','131','132'));
data x.P&parm.y&styear&endyear.d&sysdate.raw; set tempraw2;

%if &parm=88101 %then %do;;


%do runyr= &styear %to &endyear;

%put ***year=&runyr***;
data pm;
set tempraw2;
if year=&runyr;
if v ne .;
run;

*calculate means and num obs;
proc sort data=pm; by site poc q;
proc means noprint; by site poc q; var v;
output out=qtab mean=mean n=n;
data t1;
set qtab; if q=1;
mean&runyr.q1=mean;
n&runyr.q1=n;
data t2;
set qtab; if q=2;
mean&runyr.q2=mean;
n&runyr.q2=n;
data t3;
set qtab; if q=3;
mean&runyr.q3=mean;
n&runyr.q3=n;
data t4;
set qtab; if q=4;
mean&runyr.q4=mean;
n&runyr.q4=n;
run;

*merge annual stats;
data tab&runyr;
merge t1 t2 t3 t4; by site poc;
drop n mean q _freq_ _type_ nc an i;


proc sort; by site poc;

run;
%end;

%let y2 =%eval(&styear+1);

*Merge 3 year stats;
data allbut;
retain nq11 maxnq11;
array mn(12) mean&styear.q1-mean&styear.q4 mean&y2.q1-mean&y2.q4 mean&endyear.q1-mean&endyear.q4;
array nobs(12) n&styear.q1-n&styear.q4 n&y2.q1-n&y2.q4 n&endyear.q1-n&endyear.q4;
merge tab&styear tab&y2 tab&endyear;
by site poc;nq11=0;
maxnq11=0;
do i=1 to 12;

    if nobs(i) ge 11 then nq11+1;
    if nobs(i) lt 11 then do;
        if nq11 ne 0 then do;
            if nq11 ge 8 then nq11=8;
            else if nq11 ge 4 then nq11=4;
            maxnq11=max(of maxnq11 nq11);
            if maxnq11=nq11 then do; eq=i-1; bq=eq-nq11+1; end;
            nq11=0;
        end;
    end;
    else if i=12 then do;
            if nq11=12 then nq11=12;
            else if nq11 ge 8 then nq11=8;
            else if nq11 ge 4 then nq11=4;
            maxnq11=max(of maxnq11 nq11);
            if maxnq11=nq11 then do; eq=i; bq=eq-nq11+1; end;
    end;
if maxnq11 lt 4 then do; bq=0; eq=0; maxnq11=.; end;
end;

do i=1 to 12;
if i lt bq or i gt eq then do;
mn(i)=.;
nobs(i)=.;
end;
end;
annmean=mean(of mean&styear.q1-mean&styear.q4
mean&y2.q1-mean&y2.q4 mean&endyear.q1-mean&endyear.q4);
if maxnq11 ge 4;
run;

proc sort; by site poc;
data allbut2; set allbut; by site poc;
if first.site;

data keepq (keep=site poc bq eq);
set allbut2;

data tempraw2 (keep=site poc q v meth zdate); set tempraw;
if year=&y2 then q=q+4;
if year=&endyear then q=q+8;
if v ne .;
run;

data keepraw; merge keepq tempraw2; by site poc;
if q ge bq and q le eq;
run;

data x.p&parm.raw_meetscomp; set keepraw;


*Calculate 98th percentile;
proc sql;
create table cts as select distinct site,poc,count(*) as an
from keepraw group by site,poc;

proc sort data=keepraw; by site poc descending v;
data pmreg; merge cts keepraw; by site poc;

data p98 (keep=site poc pct98 an nc);
set pmreg;by site poc descending v;
retain nc np;
if first.poc then do;
nc=an-int(.98*an);
np=0;
end;

np+1;
if np = nc then do;
PCT98=round(v,.1);
output;
end;
run;

proc sort data=keepraw;
by site poc;
proc univariate noprint data=keepraw;
by site poc;
var v;
output out=uniout min=MIN p5=PCT05 q1=PCT25 median=MEDIAN q3=PCT75
p95=PCT95 max=MAX p99=pct99;;
run;

data x.finalp&parm.y&styear&endyear;
merge uniout allbut2 p98; by site poc;
if  maxnq11 gt 0;
run;
%end;
%mend;
run;

libname old 'd:\pmdv';
libname x 'D:\pm naaqs\summer03';
%parmpull(x,88101,2000,2002,y,sme,newday0327);
run;